Struct random_access_disk::RandomAccessDisk [−][src]
pub struct RandomAccessDisk { /* fields omitted */ }Main constructor.
Methods
impl RandomAccessDisk[src]
impl RandomAccessDiskTrait Implementations
impl Debug for RandomAccessDisk[src]
impl Debug for RandomAccessDiskfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl RandomAccess for RandomAccessDisk[src]
impl RandomAccess for RandomAccessDisktype Error = Error
An error.
fn write(&mut self, offset: usize, data: &[u8]) -> Result<(), Self::Error>[src]
fn write(&mut self, offset: usize, data: &[u8]) -> Result<(), Self::Error>Write bytes at an offset to the backend.
fn read(&mut self, offset: usize, length: usize) -> Result<Vec<u8>, Self::Error>[src]
fn read(&mut self, offset: usize, length: usize) -> Result<Vec<u8>, Self::Error>Read a sequence of bytes at an offset from the backend.
fn read_to_writer(
&mut self,
_offset: usize,
_length: usize,
_buf: &mut impl Write
) -> Result<(), Self::Error>[src]
fn read_to_writer(
&mut self,
_offset: usize,
_length: usize,
_buf: &mut impl Write
) -> Result<(), Self::Error>Read a sequence of bytes at an offset from the backend.
fn del(&mut self, _offset: usize, _length: usize) -> Result<(), Self::Error>[src]
fn del(&mut self, _offset: usize, _length: usize) -> Result<(), Self::Error>Delete a sequence of bytes at an offset from the backend.
impl Drop for RandomAccessDisk[src]
impl Drop for RandomAccessDiskAuto Trait Implementations
impl Send for RandomAccessDisk
impl Send for RandomAccessDiskimpl Sync for RandomAccessDisk
impl Sync for RandomAccessDisk